[libgdata] [gd] Add #defines for GData namespace objects



commit a464563b8203381db2b708e65998ef6ae3ed6012
Author: Philip Withnall <philip tecnocode co uk>
Date:   Sat Mar 27 00:18:49 2010 +0000

    [gd] Add #defines for GData namespace objects

 docs/reference/gdata-sections.txt  |   56 +++++++++++-
 gdata/gd/gdata-gd-email-address.c  |    2 +-
 gdata/gd/gdata-gd-email-address.h  |   27 ++++++
 gdata/gd/gdata-gd-im-address.c     |    4 +-
 gdata/gd/gdata-gd-im-address.h     |  108 +++++++++++++++++++++
 gdata/gd/gdata-gd-organization.c   |    2 +-
 gdata/gd/gdata-gd-organization.h   |   18 ++++
 gdata/gd/gdata-gd-phone-number.c   |    2 +-
 gdata/gd/gdata-gd-phone-number.h   |  180 ++++++++++++++++++++++++++++++++++++
 gdata/gd/gdata-gd-postal-address.c |    9 +-
 gdata/gd/gdata-gd-postal-address.h |   27 ++++++
 gdata/gd/gdata-gd-reminder.c       |    2 +-
 gdata/gd/gdata-gd-reminder.h       |   27 ++++++
 gdata/gd/gdata-gd-where.c          |    3 +-
 gdata/gd/gdata-gd-where.h          |   27 ++++++
 gdata/gd/gdata-gd-who.c            |    3 +-
 gdata/gd/gdata-gd-who.h            |   38 ++++++++
 gdata/tests/calendar.c             |    2 +-
 gdata/tests/contacts.c             |   15 ++--
 gdata/tests/general.c              |   34 ++++----
 20 files changed, 545 insertions(+), 41 deletions(-)
---
diff --git a/docs/reference/gdata-sections.txt b/docs/reference/gdata-sections.txt
index be880d5..a34db15 100644
--- a/docs/reference/gdata-sections.txt
+++ b/docs/reference/gdata-sections.txt
@@ -786,6 +786,8 @@ GDataGeneratorPrivate
 <SECTION>
 <FILE>gdata-gd-organization</FILE>
 <TITLE>GDataGDOrganization</TITLE>
+GDATA_GD_ORGANIZATION_WORK
+GDATA_GD_ORGANIZATION_OTHER
 GDataGDOrganization
 GDataGDOrganizationClass
 gdata_gd_organization_new
@@ -852,6 +854,10 @@ GDataGDWhenPrivate
 <SECTION>
 <FILE>gdata-gd-who</FILE>
 <TITLE>GDataGDWho</TITLE>
+GDATA_GD_WHO_EVENT_ATTENDEE
+GDATA_GD_WHO_EVENT_ORGANIZER
+GDATA_GD_WHO_EVENT_PERFORMER
+GDATA_GD_WHO_EVENT_SPEAKER
 GDataGDWho
 GDataGDWhoClass
 gdata_gd_who_new
@@ -877,6 +883,9 @@ GDataGDWhoPrivate
 <SECTION>
 <FILE>gdata-gd-where</FILE>
 <TITLE>GDataGDWhere</TITLE>
+GDATA_GD_WHERE_EVENT
+GDATA_GD_WHERE_EVENT_ALTERNATE
+GDATA_GD_WHERE_EVENT_PARKING
 GDataGDWhere
 GDataGDWhereClass
 gdata_gd_where_new
@@ -902,6 +911,9 @@ GDataGDWherePrivate
 <SECTION>
 <FILE>gdata-gd-email-address</FILE>
 <TITLE>GDataGDEmailAddress</TITLE>
+GDATA_GD_EMAIL_ADDRESS_HOME
+GDATA_GD_EMAIL_ADDRESS_OTHER
+GDATA_GD_EMAIL_ADDRESS_WORK
 GDataGDEmailAddress
 GDataGDEmailAddressClass
 gdata_gd_email_address_new
@@ -931,6 +943,18 @@ GDataGDEmailAddressPrivate
 <SECTION>
 <FILE>gdata-gd-im-address</FILE>
 <TITLE>GDataGDIMAddress</TITLE>
+GDATA_GD_IM_ADDRESS_HOME
+GDATA_GD_IM_ADDRESS_NETMEETING
+GDATA_GD_IM_ADDRESS_OTHER
+GDATA_GD_IM_ADDRESS_WORK
+GDATA_GD_IM_PROTOCOL_AIM
+GDATA_GD_IM_PROTOCOL_LIVE_MESSENGER
+GDATA_GD_IM_PROTOCOL_YAHOO_MESSENGER
+GDATA_GD_IM_PROTOCOL_SKYPE
+GDATA_GD_IM_PROTOCOL_QQ
+GDATA_GD_IM_PROTOCOL_GOOGLE_TALK
+GDATA_GD_IM_PROTOCOL_ICQ
+GDATA_GD_IM_PROTOCOL_JABBER
 GDataGDIMAddress
 GDataGDIMAddressClass
 gdata_gd_im_address_new
@@ -960,14 +984,17 @@ GDataGDIMAddressPrivate
 <SECTION>
 <FILE>gdata-gd-postal-address</FILE>
 <TITLE>GDataGDPostalAddress</TITLE>
-GDataGDPostalAddress
-GDataGDPostalAddressClass
+GDATA_GD_POSTAL_ADDRESS_WORK
+GDATA_GD_POSTAL_ADDRESS_HOME
+GDATA_GD_POSTAL_ADDRESS_OTHER
 GDATA_GD_ADDRESS_USAGE_GENERAL
 GDATA_GD_ADDRESS_USAGE_LOCAL
 GDATA_GD_MAIL_CLASS_BOTH
 GDATA_GD_MAIL_CLASS_LETTERS
 GDATA_GD_MAIL_CLASS_NEITHER
 GDATA_GD_MAIL_CLASS_PARCELS
+GDataGDPostalAddress
+GDataGDPostalAddressClass
 gdata_gd_postal_address_new
 gdata_gd_postal_address_compare
 gdata_gd_postal_address_get_address
@@ -1018,6 +1045,26 @@ GDataGDPostalAddressPrivate
 <SECTION>
 <FILE>gdata-gd-phone-number</FILE>
 <TITLE>GDataGDPhoneNumber</TITLE>
+GDATA_GD_PHONE_NUMBER_ASSISTANT
+GDATA_GD_PHONE_NUMBER_CALLBACK
+GDATA_GD_PHONE_NUMBER_CAR
+GDATA_GD_PHONE_NUMBER_COMPANY_MAIN
+GDATA_GD_PHONE_NUMBER_FAX
+GDATA_GD_PHONE_NUMBER_HOME
+GDATA_GD_PHONE_NUMBER_HOME_FAX
+GDATA_GD_PHONE_NUMBER_ISDN
+GDATA_GD_PHONE_NUMBER_MAIN
+GDATA_GD_PHONE_NUMBER_MOBILE
+GDATA_GD_PHONE_NUMBER_OTHER
+GDATA_GD_PHONE_NUMBER_OTHER_FAX
+GDATA_GD_PHONE_NUMBER_PAGER
+GDATA_GD_PHONE_NUMBER_RADIO
+GDATA_GD_PHONE_NUMBER_TELEX
+GDATA_GD_PHONE_NUMBER_TTY_TDD
+GDATA_GD_PHONE_NUMBER_WORK
+GDATA_GD_PHONE_NUMBER_WORK_FAX
+GDATA_GD_PHONE_NUMBER_WORK_MOBILE
+GDATA_GD_PHONE_NUMBER_WORK_PAGER
 GDataGDPhoneNumber
 GDataGDPhoneNumberClass
 gdata_gd_phone_number_new
@@ -1047,6 +1094,9 @@ GDataGDPhoneNumberPrivate
 <SECTION>
 <FILE>gdata-gd-reminder</FILE>
 <TITLE>GDataGDReminder</TITLE>
+GDATA_GD_REMINDER_ALERT
+GDATA_GD_REMINDER_EMAIL
+GDATA_GD_REMINDER_SMS
 GDataGDReminder
 GDataGDReminderClass
 gdata_gd_reminder_new
@@ -1418,7 +1468,7 @@ GDataPicasaWebFilePrivate
 <FILE>gdata-documents-entry</FILE>
 <TITLE>GDataDocumentsEntry</TITLE>
 GDATA_DOCUMENTS_ACCESS_ROLE_OWNER
-GDATA_DOCUMENTS_ACCESS_ROLE_ROOT
+GDATA_DOCUMENTS_ACCESS_ROLE_WRITER
 GDATA_DOCUMENTS_ACCESS_ROLE_READER
 GDataDocumentsEntry
 GDataDocumentsEntryClass
diff --git a/gdata/gd/gdata-gd-email-address.c b/gdata/gd/gdata-gd-email-address.c
index 8895c28..2255be4 100644
--- a/gdata/gd/gdata-gd-email-address.c
+++ b/gdata/gd/gdata-gd-email-address.c
@@ -98,7 +98,7 @@ gdata_gd_email_address_class_init (GDataGDEmailAddressClass *klass)
 	/**
 	 * GDataGDEmailAddress:relation-type:
 	 *
-	 * A programmatic value that identifies the type of e-mail address.
+	 * A programmatic value that identifies the type of e-mail address. For example: %GDATA_GD_EMAIL_ADDRESS_HOME or %GDATA_GD_EMAIL_ADDRESS_WORK.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdEmail";>GData specification</ulink>.
diff --git a/gdata/gd/gdata-gd-email-address.h b/gdata/gd/gdata-gd-email-address.h
index fa78a0c..e59a81b 100644
--- a/gdata/gd/gdata-gd-email-address.h
+++ b/gdata/gd/gdata-gd-email-address.h
@@ -27,6 +27,33 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GDATA_GD_EMAIL_ADDRESS_HOME:
+ *
+ * The relation type URI for a home e-mail address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_EMAIL_ADDRESS_HOME "http://schemas.google.com/g/2005#home";
+
+/**
+ * GDATA_GD_EMAIL_ADDRESS_OTHER:
+ *
+ * The relation type URI for a miscellaneous e-mail address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_EMAIL_ADDRESS_OTHER "http://schemas.google.com/g/2005#other";
+
+/**
+ * GDATA_GD_EMAIL_ADDRESS_WORK:
+ *
+ * The relation type URI for a work e-mail address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_EMAIL_ADDRESS_WORK "http://schemas.google.com/g/2005#work";
+
 #define GDATA_TYPE_GD_EMAIL_ADDRESS		(gdata_gd_email_address_get_type ())
 #define GDATA_GD_EMAIL_ADDRESS(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_GD_EMAIL_ADDRESS, GDataGDEmailAddress))
 #define GDATA_GD_EMAIL_ADDRESS_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_GD_EMAIL_ADDRESS, GDataGDEmailAddressClass))
diff --git a/gdata/gd/gdata-gd-im-address.c b/gdata/gd/gdata-gd-im-address.c
index 3bdf18f..22c3462 100644
--- a/gdata/gd/gdata-gd-im-address.c
+++ b/gdata/gd/gdata-gd-im-address.c
@@ -98,7 +98,7 @@ gdata_gd_im_address_class_init (GDataGDIMAddressClass *klass)
 	/**
 	 * GDataGDIMAddress:protocol:
 	 *
-	 * Identifies the IM network.
+	 * Identifies the IM network. For example: %GDATA_GD_IM_PROTOCOL_JABBER or %GDATA_GD_IM_PROTOCOL_GOOGLE_TALK.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdIm";>GData specification</ulink>.
@@ -114,7 +114,7 @@ gdata_gd_im_address_class_init (GDataGDIMAddressClass *klass)
 	/**
 	 * GDataGDIMAddress:relation-type:
 	 *
-	 * A programmatic value that identifies the type of IM address.
+	 * A programmatic value that identifies the type of IM address. For example: %GDATA_GD_IM_ADDRESS_HOME or %GDATA_GD_IM_ADDRESS_WORK.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdIm";>GData specification</ulink>.
diff --git a/gdata/gd/gdata-gd-im-address.h b/gdata/gd/gdata-gd-im-address.h
index 0c4e97d..92d7496 100644
--- a/gdata/gd/gdata-gd-im-address.h
+++ b/gdata/gd/gdata-gd-im-address.h
@@ -27,6 +27,114 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GDATA_GD_IM_ADDRESS_HOME:
+ *
+ * The relation type URI for a home IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_ADDRESS_HOME "http://schemas.google.com/g/2005#home";
+
+/**
+ * GDATA_GD_IM_ADDRESS_NETMEETING:
+ *
+ * The relation type URI for a Microsoft NetMeeting IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_ADDRESS_NETMEETING "http://schemas.google.com/g/2005#netmeeting";
+
+/**
+ * GDATA_GD_IM_ADDRESS_OTHER:
+ *
+ * The relation type URI for a miscellaneous IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_ADDRESS_OTHER "http://schemas.google.com/g/2005#other";
+
+/**
+ * GDATA_GD_IM_ADDRESS_WORK:
+ *
+ * The relation type URI for a work IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_ADDRESS_WORK "http://schemas.google.com/g/2005#work";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_AIM:
+ *
+ * The protocol type URI for an AIM IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_AIM "http://schemas.google.com/g/2005#AIM";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_LIVE_MESSENGER:
+ *
+ * The protocol type URI for an Windows Live Messenger IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_LIVE_MESSENGER "http://schemas.google.com/g/2005#MSN";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_YAHOO_MESSENGER:
+ *
+ * The protocol type URI for a Yahoo! Messenger IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_YAHOO_MESSENGER "http://schemas.google.com/g/2005#YAHOO";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_SKYPE:
+ *
+ * The protocol type URI for a Skype IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_SKYPE "http://schemas.google.com/g/2005#SKYPE";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_QQ:
+ *
+ * The protocol type URI for a QQ IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_QQ "http://schemas.google.com/g/2005#QQ";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_GOOGLE_TALK:
+ *
+ * The protocol type URI for a Google Talk IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_GOOGLE_TALK "http://schemas.google.com/g/2005#GOOGLE_TALK";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_ICQ:
+ *
+ * The protocol type URI for an ICQ IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_ICQ "http://schemas.google.com/g/2005#ICQ";
+
+/**
+ * GDATA_GD_IM_PROTOCOL_JABBER:
+ *
+ * The protocol type URI for a Jabber IM address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_IM_PROTOCOL_JABBER "http://schemas.google.com/g/2005#JABBER";
+
 #define GDATA_TYPE_GD_IM_ADDRESS		(gdata_gd_im_address_get_type ())
 #define GDATA_GD_IM_ADDRESS(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_GD_IM_ADDRESS, GDataGDIMAddress))
 #define GDATA_GD_IM_ADDRESS_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_GD_IM_ADDRESS, GDataGDIMAddressClass))
diff --git a/gdata/gd/gdata-gd-organization.c b/gdata/gd/gdata-gd-organization.c
index 130d4fe..9337a4c 100644
--- a/gdata/gd/gdata-gd-organization.c
+++ b/gdata/gd/gdata-gd-organization.c
@@ -130,7 +130,7 @@ gdata_gd_organization_class_init (GDataGDOrganizationClass *klass)
 	/**
 	 * GDataGDOrganization:relation-type:
 	 *
-	 * A programmatic value that identifies the type of organization.
+	 * A programmatic value that identifies the type of organization. For example: %GDATA_GD_ORGANIZATION_WORK or %GDATA_GD_ORGANIZATION_OTHER.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdOrganization";>GData specification</ulink>.
diff --git a/gdata/gd/gdata-gd-organization.h b/gdata/gd/gdata-gd-organization.h
index 3d3ad0b..c37486c 100644
--- a/gdata/gd/gdata-gd-organization.h
+++ b/gdata/gd/gdata-gd-organization.h
@@ -28,6 +28,24 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GDATA_GD_ORGANIZATION_WORK:
+ *
+ * The relation type URI for a work organization.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_ORGANIZATION_WORK "http://schemas.google.com/g/2005#work";
+
+/**
+ * GDATA_GD_ORGANIZATION_OTHER:
+ *
+ * The relation type URI for a miscellaneous organization.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_ORGANIZATION_OTHER "http://schemas.google.com/g/2005#other";
+
 #define GDATA_TYPE_GD_ORGANIZATION		(gdata_gd_organization_get_type ())
 #define GDATA_GD_ORGANIZATION(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_GD_ORGANIZATION, GDataGDOrganization))
 #define GDATA_GD_ORGANIZATION_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_GD_ORGANIZATION, GDataGDOrganizationClass))
diff --git a/gdata/gd/gdata-gd-phone-number.c b/gdata/gd/gdata-gd-phone-number.c
index f4d3840..fc22232 100644
--- a/gdata/gd/gdata-gd-phone-number.c
+++ b/gdata/gd/gdata-gd-phone-number.c
@@ -119,7 +119,7 @@ gdata_gd_phone_number_class_init (GDataGDPhoneNumberClass *klass)
 	/**
 	 * GDataGDPhoneNumber:relation-type:
 	 *
-	 * A programmatic value that identifies the type of phone number.
+	 * A programmatic value that identifies the type of phone number. For example: %GDATA_GD_PHONE_NUMBER_WORK or %GDATA_GD_PHONE_NUMBER_PAGER.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber";>GData specification</ulink>.
diff --git a/gdata/gd/gdata-gd-phone-number.h b/gdata/gd/gdata-gd-phone-number.h
index 37b9279..00f8faa 100644
--- a/gdata/gd/gdata-gd-phone-number.h
+++ b/gdata/gd/gdata-gd-phone-number.h
@@ -27,6 +27,186 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GDATA_GD_PHONE_NUMBER_ASSISTANT:
+ *
+ * The relation type URI for the phone number of an assistant.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_ASSISTANT "http://schemas.google.com/g/2005#assistant";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_CALLBACK:
+ *
+ * The relation type URI for the phone number of a callback service.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_CALLBACK "http://schemas.google.com/g/2005#callback";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_CAR:
+ *
+ * The relation type URI for the phone number of a car phone.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_CAR "http://schemas.google.com/g/2005#car";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_COMPANY_MAIN:
+ *
+ * The relation type URI for the main phone number of a company.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_COMPANY_MAIN "http://schemas.google.com/g/2005#company_main";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_FAX:
+ *
+ * The relation type URI for the phone number of a fax machine.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_FAX "http://schemas.google.com/g/2005#fax";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_HOME:
+ *
+ * The relation type URI for a home phone number.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_HOME "http://schemas.google.com/g/2005#home";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_HOME_FAX:
+ *
+ * The relation type URI for the phone number of a home fax machine.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_HOME_FAX "http://schemas.google.com/g/2005#home_fax";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_ISDN:
+ *
+ * The relation type URI for the phone number of an ISDN phone.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_ISDN "http://schemas.google.com/g/2005#isdn";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_MAIN:
+ *
+ * The relation type URI for the main phone number of a person.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_MAIN "http://schemas.google.com/g/2005#main";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_MOBILE:
+ *
+ * The relation type URI for the phone number of a mobile phone.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_MOBILE "http://schemas.google.com/g/2005#mobile";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_OTHER:
+ *
+ * The relation type URI for a miscellaneous phone number.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_OTHER "http://schemas.google.com/g/2005#other";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_OTHER_FAX:
+ *
+ * The relation type URI for a miscellaneous fax machine's phone number.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_OTHER_FAX "http://schemas.google.com/g/2005#other_fax";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_PAGER:
+ *
+ * The relation type URI for the phone number of a pager.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_PAGER "http://schemas.google.com/g/2005#pager";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_RADIO:
+ *
+ * The relation type URI for the phone number of a radio phone.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_RADIO "http://schemas.google.com/g/2005#radio";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_TELEX:
+ *
+ * The relation type URI for the phone number of a telex machine.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_TELEX "http://schemas.google.com/g/2005#telex";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_TTY_TDD:
+ *
+ * The relation type URI for the phone number of a TTY TTD.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_TTY_TDD "http://schemas.google.com/g/2005#tty_tdd";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_WORK:
+ *
+ * The relation type URI for the phone number of a work place.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_WORK "http://schemas.google.com/g/2005#work";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_WORK_FAX:
+ *
+ * The relation type URI for the phone number of a work fax machine.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_WORK_FAX "http://schemas.google.com/g/2005#work_fax";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_WORK_MOBILE:
+ *
+ * The relation type URI for the phone number of a work mobile phone.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_WORK_MOBILE "http://schemas.google.com/g/2005#work_mobile";
+
+/**
+ * GDATA_GD_PHONE_NUMBER_WORK_PAGER:
+ *
+ * The relation type URI for the phone number of a work pager.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_PHONE_NUMBER_WORK_PAGER "http://schemas.google.com/g/2005#work_pager";
+
 #define GDATA_TYPE_GD_PHONE_NUMBER		(gdata_gd_phone_number_get_type ())
 #define GDATA_GD_PHONE_NUMBER(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_GD_PHONE_NUMBER, GDataGDPhoneNumber))
 #define GDATA_GD_PHONE_NUMBER_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_GD_PHONE_NUMBER, GDataGDPhoneNumberClass))
diff --git a/gdata/gd/gdata-gd-postal-address.h b/gdata/gd/gdata-gd-postal-address.h
index 7528a79..898fd31 100644
--- a/gdata/gd/gdata-gd-postal-address.h
+++ b/gdata/gd/gdata-gd-postal-address.h
@@ -28,6 +28,33 @@
 G_BEGIN_DECLS
 
 /**
+ * GDATA_GD_POSTAL_ADDRESS_WORK:
+ *
+ * The relation type URI for the postal address of a workplace.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_POSTAL_ADDRESS_WORK "http://schemas.google.com/g/2005#work";
+
+/**
+ * GDATA_GD_POSTAL_ADDRESS_HOME:
+ *
+ * The relation type URI for the postal address of a home.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_POSTAL_ADDRESS_HOME "http://schemas.google.com/g/2005#home";
+
+/**
+ * GDATA_GD_POSTAL_ADDRESS_OTHER:
+ *
+ * The relation type URI for a miscellaneous postal address.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_POSTAL_ADDRESS_OTHER "http://schemas.google.com/g/2005#other";
+
+/**
  * GDATA_GD_MAIL_CLASS_BOTH:
  *
  * Parcels and letters can be sent to the address. Value for #GDataGDPostalAddress:mail-class.
diff --git a/gdata/gd/gdata-gd-reminder.c b/gdata/gd/gdata-gd-reminder.c
index daa7fce..d8c98a8 100644
--- a/gdata/gd/gdata-gd-reminder.c
+++ b/gdata/gd/gdata-gd-reminder.c
@@ -80,7 +80,7 @@ gdata_gd_reminder_class_init (GDataGDReminderClass *klass)
 	/**
 	 * GDataGDReminder:method:
 	 *
-	 * The notification method the reminder should use.
+	 * The notification method the reminder should use. For example: %GDATA_GD_REMINDER_ALERT or %GDATA_GD_REMINDER_EMAIL.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdReminder";>GData specification</ulink>.
diff --git a/gdata/gd/gdata-gd-reminder.h b/gdata/gd/gdata-gd-reminder.h
index 3504b08..c3e37ad 100644
--- a/gdata/gd/gdata-gd-reminder.h
+++ b/gdata/gd/gdata-gd-reminder.h
@@ -27,6 +27,33 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GDATA_GD_REMINDER_ALERT:
+ *
+ * The #GDataGDReminder:method for an alert to appear in the user's browser.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_REMINDER_ALERT "alert"
+
+/**
+ * GDATA_GD_REMINDER_EMAIL:
+ *
+ * The #GDataGDReminder:method for an alert to be sent to the user by e-mail.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_REMINDER_EMAIL "email"
+
+/**
+ * GDATA_GD_REMINDER_SMS:
+ *
+ * The #GDataGDReminder:method for an alert to be sent to the user by SMS.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_REMINDER_SMS "sms"
+
 #define GDATA_TYPE_GD_REMINDER		(gdata_gd_reminder_get_type ())
 #define GDATA_GD_REMINDER(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_GD_REMINDER, GDataGDReminder))
 #define GDATA_GD_REMINDER_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_GD_REMINDER, GDataGDReminderClass))
diff --git a/gdata/gd/gdata-gd-where.c b/gdata/gd/gdata-gd-where.c
index ccf79eb..50ab505 100644
--- a/gdata/gd/gdata-gd-where.c
+++ b/gdata/gd/gdata-gd-where.c
@@ -82,7 +82,8 @@ gdata_gd_where_class_init (GDataGDWhereClass *klass)
 	/**
 	 * GDataGDWhere:relation-type:
 	 *
-	 * Specifies the relationship between the containing entity and the contained location.
+	 * Specifies the relationship between the containing entity and the contained location. For example: %GDATA_GD_WHERE_EVENT or
+	 * %GDATA_GD_WHERE_EVENT_PARKING.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdWhere";>GData specification</ulink>.
diff --git a/gdata/gd/gdata-gd-where.h b/gdata/gd/gdata-gd-where.h
index ccfeaba..b1d7f7d 100644
--- a/gdata/gd/gdata-gd-where.h
+++ b/gdata/gd/gdata-gd-where.h
@@ -27,6 +27,33 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GDATA_GD_WHERE_EVENT:
+ *
+ * The relation type URI for an event location.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_WHERE_EVENT "http://schemas.google.com/g/2005#event";
+
+/**
+ * GDATA_GD_WHERE_EVENT_ALTERNATE:
+ *
+ * The relation type URI for an alternate event location, such as a video conference site.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_WHERE_EVENT_ALTERNATE "http://schemas.google.com/g/2005#event.alternate";
+
+/**
+ * GDATA_GD_WHERE_EVENT_PARKING:
+ *
+ * The relation type URI for an event's parking lot.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_WHERE_EVENT_PARKING "http://schemas.google.com/g/2005#event.parking";
+
 #define GDATA_TYPE_GD_WHERE		(gdata_gd_where_get_type ())
 #define GDATA_GD_WHERE(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_GD_WHERE, GDataGDWhere))
 #define GDATA_GD_WHERE_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_GD_WHERE, GDataGDWhereClass))
diff --git a/gdata/gd/gdata-gd-who.c b/gdata/gd/gdata-gd-who.c
index 3c6e200..ab9dfab 100644
--- a/gdata/gd/gdata-gd-who.c
+++ b/gdata/gd/gdata-gd-who.c
@@ -82,7 +82,8 @@ gdata_gd_who_class_init (GDataGDWhoClass *klass)
 	/**
 	 * GDataGDWho:relation-type:
 	 *
-	 * Specifies the relationship between the containing entity and the contained person.
+	 * Specifies the relationship between the containing entity and the contained person. For example: %GDATA_GD_WHO_EVENT_PERFORMER or
+	 * %GDATA_GD_WHO_EVENT_ATTENDEE.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdWho";>GData specification</ulink>.
diff --git a/gdata/gd/gdata-gd-who.h b/gdata/gd/gdata-gd-who.h
index 0bda4a4..708bbde 100644
--- a/gdata/gd/gdata-gd-who.h
+++ b/gdata/gd/gdata-gd-who.h
@@ -27,6 +27,44 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GDATA_GD_WHO_EVENT_ATTENDEE:
+ *
+ * The relation type URI for a general meeting or event attendee.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_WHO_EVENT_ATTENDEE "http://schemas.google.com/g/2005#event.attendee";
+
+/**
+ * GDATA_GD_WHO_EVENT_ORGANIZER:
+ *
+ * The relation type URI for an event organizer (not necessarily an attendee).
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_WHO_EVENT_ORGANIZER "http://schemas.google.com/g/2005#event.organizer";
+
+/**
+ * GDATA_GD_WHO_EVENT_PERFORMER:
+ *
+ * The relation type URI for an event performer, which is similar to %GDATA_GD_WHO_EVENT_SPEAKER, but with more emphasis on art rather than speaking.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_WHO_EVENT_PERFORMER "http://schemas.google.com/g/2005#event.performer";
+
+/**
+ * GDATA_GD_WHO_EVENT_SPEAKER:
+ *
+ * The relation type URI for a speaker at an event.
+ *
+ * Since: 0.7.0
+ **/
+#define GDATA_GD_WHO_EVENT_SPEAKER "http://schemas.google.com/g/2005#event.speaker";
+
+/* TODO: Message kind relation types (http://code.google.com/apis/gdata/docs/2.0/elements.html#gdWho) */
+
 #define GDATA_TYPE_GD_WHO		(gdata_gd_who_get_type ())
 #define GDATA_GD_WHO(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_GD_WHO, GDataGDWho))
 #define GDATA_GD_WHO_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_GD_WHO, GDataGDWhoClass))
diff --git a/gdata/tests/calendar.c b/gdata/tests/calendar.c
index ddac509..005b0e5 100644
--- a/gdata/tests/calendar.c
+++ b/gdata/tests/calendar.c
@@ -248,7 +248,7 @@ test_insert_simple (gconstpointer service)
 	where = gdata_gd_where_new (NULL, "Rolling Lawn Courts", NULL);
 	gdata_calendar_event_add_place (event, where);
 	g_object_unref (where);
-	who = gdata_gd_who_new ("http://schemas.google.com/g/2005#event.organizer";, "John Smithâ?½", "john smith example com");
+	who = gdata_gd_who_new (GDATA_GD_WHO_EVENT_ORGANIZER, "John Smithâ?½", "john smith example com");
 	gdata_calendar_event_add_person (event, who);
 	g_object_unref (who);
 	g_time_val_from_iso8601 ("2009-04-17T15:00:00.000Z", &start_time);
diff --git a/gdata/tests/contacts.c b/gdata/tests/contacts.c
index cae7bab..1ee286b 100644
--- a/gdata/tests/contacts.c
+++ b/gdata/tests/contacts.c
@@ -197,33 +197,32 @@ test_insert_simple (gconstpointer service)
 	gdata_contacts_contact_set_birthday (contact, &date, FALSE);
 	gdata_entry_set_content (GDATA_ENTRY (contact), "Notes");
 
-	email_address1 = gdata_gd_email_address_new ("liz gmail com", "http://schemas.google.com/g/2005#work";, NULL, FALSE);
+	email_address1 = gdata_gd_email_address_new ("liz gmail com", GDATA_GD_EMAIL_ADDRESS_WORK, NULL, FALSE);
 	gdata_contacts_contact_add_email_address (contact, email_address1);
 	g_object_unref (email_address1);
 
-	email_address2 = gdata_gd_email_address_new ("liz example org", "http://schemas.google.com/g/2005#home";, NULL, FALSE);
+	email_address2 = gdata_gd_email_address_new ("liz example org", GDATA_GD_EMAIL_ADDRESS_HOME, NULL, FALSE);
 	gdata_contacts_contact_add_email_address (contact, email_address2);
 	g_object_unref (email_address2);
 
-	phone_number1 = gdata_gd_phone_number_new ("(206)555-1212", "http://schemas.google.com/g/2005#work";, NULL, NULL, TRUE);
+	phone_number1 = gdata_gd_phone_number_new ("(206)555-1212", GDATA_GD_PHONE_NUMBER_WORK, NULL, NULL, TRUE);
 	gdata_contacts_contact_add_phone_number (contact, phone_number1);
 	g_object_unref (phone_number1);
 
-	phone_number2 = gdata_gd_phone_number_new ("(206)555-1213", "http://schemas.google.com/g/2005#home";, NULL, NULL, FALSE);
+	phone_number2 = gdata_gd_phone_number_new ("(206)555-1213", GDATA_GD_PHONE_NUMBER_HOME, NULL, NULL, FALSE);
 	gdata_contacts_contact_add_phone_number (contact, phone_number2);
 	g_object_unref (phone_number2);
 
-	im_address = gdata_gd_im_address_new ("liz gmail com", "http://schemas.google.com/g/2005#GOOGLE_TALK";, "http://schemas.google.com/g/2005#home";,
-					      NULL, FALSE);
+	im_address = gdata_gd_im_address_new ("liz gmail com", GDATA_GD_IM_PROTOCOL_GOOGLE_TALK, GDATA_GD_IM_ADDRESS_HOME, NULL, FALSE);
 	gdata_contacts_contact_add_im_address (contact, im_address);
 	g_object_unref (im_address);
 
-	postal_address = gdata_gd_postal_address_new ("http://schemas.google.com/g/2005#work";, NULL, TRUE);
+	postal_address = gdata_gd_postal_address_new (GDATA_GD_POSTAL_ADDRESS_WORK, NULL, TRUE);
 	gdata_gd_postal_address_set_street (postal_address, "1600 Amphitheatre Pkwy Mountain View");
 	gdata_contacts_contact_add_postal_address (contact, postal_address);
 	g_object_unref (postal_address);
 
-	org = gdata_gd_organization_new ("OrgCorp", "President", "http://schemas.google.com/g/2005#work";, NULL, FALSE);
+	org = gdata_gd_organization_new ("OrgCorp", "President", GDATA_GD_ORGANIZATION_WORK, NULL, FALSE);
 	gdata_contacts_contact_add_organization (contact, org);
 	g_object_unref (org);
 
diff --git a/gdata/tests/general.c b/gdata/tests/general.c
index f65df70..7308a04 100644
--- a/gdata/tests/general.c
+++ b/gdata/tests/general.c
@@ -1265,13 +1265,13 @@ test_gd_email_address (void)
 
 	/* Check the properties */
 	g_assert_cmpstr (gdata_gd_email_address_get_address (email), ==, "fubar gmail com");
-	g_assert_cmpstr (gdata_gd_email_address_get_relation_type (email), ==, "http://schemas.google.com/g/2005#home";);
+	g_assert_cmpstr (gdata_gd_email_address_get_relation_type (email), ==, GDATA_GD_EMAIL_ADDRESS_HOME);
 	g_assert_cmpstr (gdata_gd_email_address_get_label (email), ==, "Personal & Private");
 	g_assert_cmpstr (gdata_gd_email_address_get_display_name (email), ==, "<John Smith>");
 	g_assert (gdata_gd_email_address_is_primary (email) == TRUE);
 
 	/* Compare it against another identical address */
-	email2 = gdata_gd_email_address_new ("fubar gmail com", "http://schemas.google.com/g/2005#home";, "Personal & Private", TRUE);
+	email2 = gdata_gd_email_address_new ("fubar gmail com", GDATA_GD_EMAIL_ADDRESS_HOME, "Personal & Private", TRUE);
 	gdata_gd_email_address_set_display_name (email2, "<John Smith>");
 	g_assert_cmpint (gdata_gd_email_address_compare (email, email2), ==, 0);
 
@@ -1334,17 +1334,17 @@ test_gd_im_address (void)
 
 	/* Check the properties */
 	g_assert_cmpstr (gdata_gd_im_address_get_address (im), ==, "foo bar msn com");
-	g_assert_cmpstr (gdata_gd_im_address_get_protocol (im), ==, "http://schemas.google.com/g/2005#MSN";);
-	g_assert_cmpstr (gdata_gd_im_address_get_relation_type (im), ==, "http://schemas.google.com/g/2005#home";);
+	g_assert_cmpstr (gdata_gd_im_address_get_protocol (im), ==, GDATA_GD_IM_PROTOCOL_LIVE_MESSENGER);
+	g_assert_cmpstr (gdata_gd_im_address_get_relation_type (im), ==, GDATA_GD_IM_ADDRESS_HOME);
 	g_assert (gdata_gd_im_address_get_label (im) == NULL);
 	g_assert (gdata_gd_im_address_is_primary (im) == TRUE);
 
 	/* Compare it against another identical address */
-	im2 = gdata_gd_im_address_new ("foo bar msn com", "http://schemas.google.com/g/2005#MSN";, "http://schemas.google.com/g/2005#home";, NULL, TRUE);
+	im2 = gdata_gd_im_address_new ("foo bar msn com", GDATA_GD_IM_PROTOCOL_LIVE_MESSENGER, GDATA_GD_IM_ADDRESS_HOME, NULL, TRUE);
 	g_assert_cmpint (gdata_gd_im_address_compare (im, im2), ==, 0);
 
 	/* â?¦and a different one */
-	gdata_gd_im_address_set_protocol (im2, "http://schemas.google.com/g/2005#GOOGLE_TALK";);
+	gdata_gd_im_address_set_protocol (im2, GDATA_GD_IM_PROTOCOL_GOOGLE_TALK);
 	g_assert_cmpint (gdata_gd_im_address_compare (im, im2), !=, 0);
 	g_object_unref (im2);
 
@@ -1496,7 +1496,7 @@ test_gd_organization (void)
 	/* Check the properties */
 	g_assert_cmpstr (gdata_gd_organization_get_name (org), ==, "Google, Inc.");
 	g_assert_cmpstr (gdata_gd_organization_get_title (org), ==, "<Angle Bracketeer>");
-	g_assert_cmpstr (gdata_gd_organization_get_relation_type (org), ==, "http://schemas.google.com/g/2005#work";);
+	g_assert_cmpstr (gdata_gd_organization_get_relation_type (org), ==, GDATA_GD_ORGANIZATION_WORK);
 	g_assert_cmpstr (gdata_gd_organization_get_label (org), ==, "Work & Occupation");
 	g_assert_cmpstr (gdata_gd_organization_get_department (org), ==, "Finance");
 	g_assert_cmpstr (gdata_gd_organization_get_job_description (org), ==, "Doing stuff.");
@@ -1506,7 +1506,7 @@ test_gd_organization (void)
 	g_assert (gdata_gd_organization_is_primary (org) == TRUE);
 
 	/* Compare it against another identical organization */
-	org2 = gdata_gd_organization_new ("Google, Inc.", "<Angle Bracketeer>", "http://schemas.google.com/g/2005#work";, "Work & Occupation", TRUE);
+	org2 = gdata_gd_organization_new ("Google, Inc.", "<Angle Bracketeer>", GDATA_GD_ORGANIZATION_WORK, "Work & Occupation", TRUE);
 	gdata_gd_organization_set_department (org2, "Finance");
 	gdata_gd_organization_set_location (org2, location);
 	g_assert_cmpint (gdata_gd_organization_compare (org, org2), ==, 0);
@@ -1580,12 +1580,12 @@ test_gd_phone_number (void)
 	/* Check the properties */
 	g_assert_cmpstr (gdata_gd_phone_number_get_number (phone), ==, "+1 206 555 1212");
 	g_assert_cmpstr (gdata_gd_phone_number_get_uri (phone), ==, "tel:+12065551212");
-	g_assert_cmpstr (gdata_gd_phone_number_get_relation_type (phone), ==, "http://schemas.google.com/g/2005#mobile";);
+	g_assert_cmpstr (gdata_gd_phone_number_get_relation_type (phone), ==, GDATA_GD_PHONE_NUMBER_MOBILE);
 	g_assert_cmpstr (gdata_gd_phone_number_get_label (phone), ==, "Personal & business calls only");
 	g_assert (gdata_gd_phone_number_is_primary (phone) == FALSE);
 
 	/* Compare it against another identical number */
-	phone2 = gdata_gd_phone_number_new ("+1 206 555 1212", "http://schemas.google.com/g/2005#mobile";, "Personal & business calls only",
+	phone2 = gdata_gd_phone_number_new ("+1 206 555 1212", GDATA_GD_PHONE_NUMBER_MOBILE, "Personal & business calls only",
 					    "tel:+12065551212", FALSE);
 	g_assert_cmpint (gdata_gd_phone_number_compare (phone, phone2), ==, 0);
 
@@ -1658,12 +1658,12 @@ test_gd_postal_address (void)
 	g_assert_cmpstr (gdata_gd_postal_address_get_street (postal), ==, "500 West 45th Street");
 	g_assert_cmpstr (gdata_gd_postal_address_get_city (postal), ==, "New York");
 	g_assert_cmpstr (gdata_gd_postal_address_get_postcode (postal), ==, "NY 10036");
-	g_assert_cmpstr (gdata_gd_postal_address_get_relation_type (postal), ==, "http://schemas.google.com/g/2005#home";);
+	g_assert_cmpstr (gdata_gd_postal_address_get_relation_type (postal), ==, GDATA_GD_POSTAL_ADDRESS_HOME);
 	g_assert_cmpstr (gdata_gd_postal_address_get_label (postal), ==, "Home & Safe House");
 	g_assert (gdata_gd_postal_address_is_primary (postal) == TRUE);
 
 	/* Compare it against another identical address */
-	postal2 = gdata_gd_postal_address_new ("http://schemas.google.com/g/2005#home";, "Home & Safe House", TRUE);
+	postal2 = gdata_gd_postal_address_new (GDATA_GD_POSTAL_ADDRESS_HOME, "Home & Safe House", TRUE);
 	gdata_gd_postal_address_set_street (postal2, "500 West 45th Street");
 	gdata_gd_postal_address_set_city (postal2, "New York");
 	gdata_gd_postal_address_set_postcode (postal2, "NY 10036");
@@ -1790,14 +1790,14 @@ test_gd_reminder (void)
 	g_clear_error (&error);
 
 	/* Check the properties */
-	g_assert_cmpstr (gdata_gd_reminder_get_method (reminder), ==, "alert");
+	g_assert_cmpstr (gdata_gd_reminder_get_method (reminder), ==, GDATA_GD_REMINDER_ALERT);
 	g_assert (gdata_gd_reminder_is_absolute_time (reminder) == TRUE);
 	gdata_gd_reminder_get_absolute_time (reminder, &time_val);
 	g_assert_cmpint (time_val.tv_sec, ==, 1118105700);
 	g_assert_cmpint (time_val.tv_usec, ==, 0);
 
 	/* Compare to another reminder */
-	reminder2 = gdata_gd_reminder_new ("alert", &time_val, -1);
+	reminder2 = gdata_gd_reminder_new (GDATA_GD_REMINDER_ALERT, &time_val, -1);
 	g_assert_cmpint (gdata_gd_reminder_compare (reminder, reminder2), ==, 0);
 	g_object_unref (reminder2);
 
@@ -1890,7 +1890,7 @@ test_gd_when (void)
 	g_assert_cmpint (gdata_gd_reminder_get_relative_time (GDATA_GD_REMINDER (reminders->data)), ==, 15);
 
 	/* Add another reminder */
-	reminder = gdata_gd_reminder_new ("alert", &time_val, -1);
+	reminder = gdata_gd_reminder_new (GDATA_GD_REMINDER_ALERT, &time_val, -1);
 	gdata_gd_when_add_reminder (when, reminder);
 	g_object_unref (reminder);
 
@@ -1922,12 +1922,12 @@ test_gd_where (void)
 	g_clear_error (&error);
 
 	/* Check the properties */
-	g_assert_cmpstr (gdata_gd_where_get_relation_type (where), ==, "http://schemas.google.com/g/2005#event.alternate";);
+	g_assert_cmpstr (gdata_gd_where_get_relation_type (where), ==, GDATA_GD_WHERE_EVENT_ALTERNATE);
 	g_assert_cmpstr (gdata_gd_where_get_value_string (where), ==, "Metropolis");
 	g_assert_cmpstr (gdata_gd_where_get_label (where), ==, "New York Location <videoconference>");
 
 	/* Compare it against another identical place */
-	where2 = gdata_gd_where_new ("http://schemas.google.com/g/2005#event.alternate";, "Metropolis", "New York Location <videoconference>");
+	where2 = gdata_gd_where_new (GDATA_GD_WHERE_EVENT_ALTERNATE, "Metropolis", "New York Location <videoconference>");
 	g_assert_cmpint (gdata_gd_where_compare (where, where2), ==, 0);
 
 	/* â?¦and a different one */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gdata/gd/gdata-gd-postal-address.c b/gdata/gd/gdata-gd-postal-address.c
index 6923b58..8185dc5 100644
--- a/gdata/gd/gdata-gd-postal-address.c
+++ b/gdata/gd/gdata-gd-postal-address.c
@@ -128,7 +128,8 @@ gdata_gd_postal_address_class_init (GDataGDPostalAddressClass *klass)
 	/**
 	 * GDataGDPostalAddress:relation-type:
 	 *
 	 * A programmatic value that identifies the type of postal address.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdStructuredPostalAddress";>GData specification</ulink>.
@@ -138,7 +139,7 @@ gdata_gd_postal_address_class_init (GDataGDPostalAddressClass *klass)
 	g_object_class_install_property (gobject_class, PROP_RELATION_TYPE,
 				g_param_spec_string ("relation-type",
 					"Relation type", "A programmatic value that identifies the type of postal address.",
-					NULL,
+					GDATA_GD_POSTAL_ADDRESS_WORK,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -176,7 +177,7 @@ gdata_gd_postal_address_class_init (GDataGDPostalAddressClass *klass)
 	/**
 	 * GDataGDPostalAddress:mail-class:
 	 *
-	 * Classes of mail accepted at this address.
+	 * Classes of mail accepted at this address. For example: %GDATA_GD_MAIL_CLASS_LETTERS or %GDATA_GD_MAIL_CLASS_BOTH.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdStructuredPostalAddress";>GData specification</ulink>.
@@ -192,7 +193,7 @@ gdata_gd_postal_address_class_init (GDataGDPostalAddressClass *klass)
 	/**
 	 * GDataGDPostalAddress:usage:
 	 *
-	 * The context in which this addess can be used.
+	 * The context in which this addess can be used. For example: %GDATA_GD_ADDRESS_USAGE_GENERAL or %GDATA_GD_ADDRESS_USAGE_LOCAL.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdStructuredPostalAddress";>GData specification</ulink>.
@@ -128,7 +128,8 @@ gdata_gd_postal_address_class_init (GDataGDPostalAddressClass *klass)
 	 * GDataGDPostalAddress:relation-type:
 	 *
-	 * A programmatic value that identifies the type of postal address.
+	 * A programmatic value that identifies the type of postal address. For example: %GDATA_GD_POSTAL_ADDRESS_WORK or
+	 * %GDATA_GD_POSTAL_ADDRESS_OTHER.
 	 *
 	 * For more information, see the